@@ -1,5 +1,5 @@
 pub use self::droplets::Droplet;
-pub use self::dns::{DnsRecord, DnsRecType};
+pub use self::dns::{DnsRecType, DnsRecord};
 pub use self::request::RequestBuilder;
 
 mod account;
@@ -12,4 +12,4 @@ mod ssh_keys;
 mod request;
 mod regions;
 mod sizes;
-mod arrays;
\ No newline at end of file
+mod arrays;
